@@ -4,17 +4,17 @@
 
 */
 
+#include <osmium/geom/mercator_projection.hpp>
+#include <osmium/geom/wkb.hpp>
+#include <osmium/handler.hpp>
+#include <osmium/io/any_input.hpp>
+#include <osmium/visitor.hpp>
+
 #include <cstdint>
 #include <cstdlib>
 #include <iostream>
 #include <string>
 
-#include <osmium/io/any_input.hpp>
-#include <osmium/handler.hpp>
-#include <osmium/visitor.hpp>
-#include <osmium/geom/wkb.hpp>
-#include <osmium/geom/mercator_projection.hpp>
-
 struct GeomHandler : public osmium::handler::Handler {
 
     osmium::geom::WKBFactory<osmium::geom::MercatorProjection> factory;
@@ -25,19 +25,23 @@ struct GeomHandler : public osmium::handler::Handler {
 
 };
 
-
 int main(int argc, char* argv[]) {
     if (argc != 2) {
         std::cerr << "Usage: " << argv[0] << " OSMFILE\n";
         std::exit(1);
     }
 
-    const std::string input_filename{argv[1]};
+    try {
+        const std::string input_filename{argv[1]};
 
-    osmium::io::Reader reader{input_filename};
+        osmium::io::Reader reader{input_filename};
 
-    GeomHandler handler;
-    osmium::apply(reader, handler);
-    reader.close();
+        GeomHandler handler;
+        osmium::apply(reader, handler);
+        reader.close();
+    } catch (const std::exception& e) {
+        std::cerr << e.what() << '\n';
+        std::exit(1);
+    }
 }
 
