@@ -140,23 +140,23 @@ TEST_CASE("test codepoint to utf8 encoding") {
     const char s[] = u8"\n_\u01a2_\u30dc_\U0001d11e_\U0001f680";
 
     std::string out;
-    osmium::io::detail::append_codepoint_as_utf8(0x0au, std::back_inserter(out)); // 1 utf8 byte
+    osmium::io::detail::append_codepoint_as_utf8(0x0aU, std::back_inserter(out)); // 1 utf8 byte
     REQUIRE(out.size() == 1);
     osmium::io::detail::append_codepoint_as_utf8('_', std::back_inserter(out));
     REQUIRE(out.size() == 2);
-    osmium::io::detail::append_codepoint_as_utf8(0x01a2u, std::back_inserter(out)); // 2 utf8 bytes
+    osmium::io::detail::append_codepoint_as_utf8(0x01a2U, std::back_inserter(out)); // 2 utf8 bytes
     REQUIRE(out.size() == 4);
     osmium::io::detail::append_codepoint_as_utf8('_', std::back_inserter(out));
     REQUIRE(out.size() == 5);
-    osmium::io::detail::append_codepoint_as_utf8(0x30dcu, std::back_inserter(out)); // 3 utf8 bytes
+    osmium::io::detail::append_codepoint_as_utf8(0x30dcU, std::back_inserter(out)); // 3 utf8 bytes
     REQUIRE(out.size() == 8);
     osmium::io::detail::append_codepoint_as_utf8('_', std::back_inserter(out));
     REQUIRE(out.size() == 9);
-    osmium::io::detail::append_codepoint_as_utf8(0x1d11eu, std::back_inserter(out)); // 4 utf8 bytes
+    osmium::io::detail::append_codepoint_as_utf8(0x1d11eU, std::back_inserter(out)); // 4 utf8 bytes
     REQUIRE(out.size() == 13);
     osmium::io::detail::append_codepoint_as_utf8('_', std::back_inserter(out));
     REQUIRE(out.size() == 14);
-    osmium::io::detail::append_codepoint_as_utf8(0x1f680u, std::back_inserter(out)); // 4 utf8 bytes
+    osmium::io::detail::append_codepoint_as_utf8(0x1f680U, std::back_inserter(out)); // 4 utf8 bytes
     REQUIRE(out.size() == 18);
     REQUIRE(out == s);
 }
@@ -165,15 +165,15 @@ TEST_CASE("test utf8 to codepoint decoding") {
     const char s[] = u8"\n_\u01a2_\u30dc_\U0001d11e_\U0001f680";
 
     auto it = s;
-    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x0au);
+    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x0aU);
     REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == '_');
-    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x01a2u);
+    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x01a2U);
     REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == '_');
-    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x30dcu);
+    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x30dcU);
     REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == '_');
-    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x1d11eu);
+    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x1d11eU);
     REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == '_');
-    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x1f680u);
+    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s)) == 0x1f680U);
 
     REQUIRE(*it++ == '\0');
     REQUIRE(it == std::end(s));
@@ -182,7 +182,7 @@ TEST_CASE("test utf8 to codepoint decoding") {
 TEST_CASE("Roundtrip unicode characters") {
     char s[4] = {0};
 
-    const uint32_t max_code_point = 0x10ffffu;
+    const uint32_t max_code_point = 0x10ffffU;
     for (uint32_t cp = 0; cp <= max_code_point; ++cp) {
         auto end = osmium::io::detail::append_codepoint_as_utf8(cp, s);
         const char* it = s;
@@ -201,7 +201,7 @@ TEST_CASE("incomplete Unicode codepoint") {
     const char s[] = u8"\U0001f680";
 
     auto it = s;
-    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s) - 1) == 0x1f680u);
+    REQUIRE(osmium::io::detail::next_utf8_codepoint(&it, std::end(s) - 1) == 0x1f680U);
     REQUIRE(std::distance(s, it) == 4);
 
     for (int i : {0, 1, 2, 3}) {
