@@ -36,7 +36,7 @@ public:
 
     ~MockDecompressor() noexcept final = default;
 
-    void add_node(std::string& s, int i) {
+    static void add_node(std::string& s, int i) {
         s += "<node id='";
         s += std::to_string(i);
         s += "' version='1' timestamp='2014-01-01T00:00:00Z' uid='1' user='test' changeset='1' lon='1.02' lat='1.02'/>\n";
@@ -81,9 +81,9 @@ TEST_CASE("Test Reader using MockDecompressor") {
     std::string fail_in;
 
     osmium::io::CompressionFactory::instance().register_compression(osmium::io::file_compression::gzip,
-        [](int, osmium::io::fsync) { return nullptr; },
-        [&](int) { return new MockDecompressor(fail_in); },
-        [](const char*, size_t) { return nullptr; }
+        [](int /*unused*/, osmium::io::fsync /*unused*/) { return nullptr; },
+        [&](int /*unused*/) { return new MockDecompressor(fail_in); },
+        [](const char* /*unused*/, size_t /*unused*/) { return nullptr; }
     );
 
     SECTION("fail in constructor") {
