@@ -1,13 +1,18 @@
 #include "catch.hpp"
 
-#include <algorithm>
-
 #include <osmium/builder/attr.hpp>
 #include <osmium/memory/buffer.hpp>
 #include <osmium/osm/tag.hpp>
-#include <osmium/tags/taglist.hpp>
 #include <osmium/tags/filter.hpp>
 #include <osmium/tags/regex_filter.hpp>
+#include <osmium/tags/taglist.hpp>
+
+#include <algorithm>
+#include <initializer_list>
+#include <iterator>
+#include <regex>
+#include <utility>
+#include <vector>
 
 template <class TFilter>
 void check_filter(const osmium::TagList& tag_list,
@@ -183,39 +188,37 @@ TEST_CASE("KeyValueFilter") {
 
 }
 
-TEST_CASE("RegexFilter") {
+TEST_CASE("RegexFilter matches some tags") {
     osmium::memory::Buffer buffer{10240};
 
-    SECTION("RegexFilter matches some tags") {
-        osmium::tags::RegexFilter filter{false};
-        filter.add(true, "highway", std::regex{".*_link"});
+    osmium::tags::RegexFilter filter{false};
+    filter.add(true, "highway", std::regex{".*_link"});
 
-        const osmium::TagList& tag_list1 = make_tag_list(buffer, {
-            { "highway", "primary_link" },
-            { "source", "GPS" }
-        });
-        const osmium::TagList& tag_list2 = make_tag_list(buffer, {
-            { "highway", "primary" },
-            { "source", "GPS" }
-        });
+    const osmium::TagList& tag_list1 = make_tag_list(buffer, {
+        { "highway", "primary_link" },
+        { "source", "GPS" }
+    });
+    const osmium::TagList& tag_list2 = make_tag_list(buffer, {
+        { "highway", "primary" },
+        { "source", "GPS" }
+    });
 
-        check_filter(tag_list1, filter, {true, false});
-        check_filter(tag_list2, filter, {false, false});
-    }
+    check_filter(tag_list1, filter, {true, false});
+    check_filter(tag_list2, filter, {false, false});
+}
 
-    SECTION("RegexFilter matches some tags with lvalue regex") {
-        osmium::tags::RegexFilter filter{false};
-        std::regex r{".*straße"};
-        filter.add(true, "name", r);
+TEST_CASE("RegexFilter matches some tags with lvalue regex") {
+    osmium::memory::Buffer buffer{10240};
+    osmium::tags::RegexFilter filter{false};
+    std::regex r{".*straße"};
+    filter.add(true, "name", r);
 
-        const osmium::TagList& tag_list = make_tag_list(buffer, {
-            { "highway", "primary" },
-            { "name", "Hauptstraße" }
-        });
-
-        check_filter(tag_list, filter, {false, true});
-    }
+    const osmium::TagList& tag_list = make_tag_list(buffer, {
+        { "highway", "primary" },
+        { "name", "Hauptstraße" }
+    });
 
+    check_filter(tag_list, filter, {false, true});
 }
 
 TEST_CASE("KeyPrefixFilter matches some keys") {
