@@ -1,14 +1,16 @@
 #include "catch.hpp"
 
-#include <map>
-#include <vector>
-
 #include <osmium/builder/attr.hpp>
 #include <osmium/builder/builder_helper.hpp>
 #include <osmium/memory/buffer.hpp>
 #include <osmium/osm/tag.hpp>
 
-using namespace osmium::builder::attr;
+#include <map>
+#include <string>
+#include <utility>
+#include <vector>
+
+using namespace osmium::builder::attr; // NOLINT(google-build-using-namespace)
 
 TEST_CASE("create tag list") {
     osmium::memory::Buffer buffer{10240};
