@@ -8,6 +8,11 @@ struct assert_error : public std::runtime_error {
     explicit assert_error(const char* what_arg) : std::runtime_error(what_arg) {
     }
 };
+
+#ifdef assert
+#undef assert
+#endif
+
 #define assert(x) if (!(x)) { throw assert_error{#x}; }
 
 #include <osmium/util/cast.hpp>
